# $Id: Channel.pm 28 2006-05-20 17:45:01Z maletin $
# $URL: svn+ssh://svn.berlios.de/svnroot/repos/cpan-teamspeak/cpan/trunk/lib/Teamspeak/Channel.pm $

package Teamspeak::Channel;

use strict;
use vars qw( $VERSION );
$VERSION = '0.5';

1;
